@@ -6,9 +6,8 @@ import click as click
 from dvpn.config.constants import PublicVars
 from dvpn.config.paths import secret_path
 from dvpn.modules.tools import connect
-from dvpn.modules.windows import open_gui
-
 from dvpn.modules.vpncli import VpnCli
+from dvpn.modules.windows import open_gui
 
 
 @click.group()
@@ -33,14 +32,12 @@ def _auto():
     VpnCli.check_accessed()
 
 
-
-
 @cli.command()
 def gui():
     open_gui()
 
 
-if __name__ == '__main__':
+def main():
     if "gui" not in argv:
         if not secret_path.exists():
             print(
@@ -52,6 +49,7 @@ if __name__ == '__main__':
 
         if len(PublicVars().credentials.keys()) == 0:
             print(
-                "No Credentials Found please make sure to add your VPNs before continuing "
+                "No Credentials Found please make sure to add your VPNs before "
+                "continuing "
                 "with dvpn gui")
     cli()
